clear all

%Simulation 2: Heterogeneous Agents with Complete Markets%


syms p1 p2 p3 p4 p5 p6 p7 p8 p9;
syms x1o x2o x3o x4o x5o x6o x7o x8o x9o;
syms x1p x2p x3p x4p x5p x6p x7p x8p x9p;
syms z1 z2;

%values parameters

p1=1;
e=2;
h=2;

H=.2;
E=.1;

delta=1;

qo=.9;
qp=.5;

%endowments adding deliveries of assets at final endowments
e1o=20;
e2o=20;
e3o=20;
e4o=22;
e5o=21.1;
e6o=22;
e7o=21.1;
e8o=21.2;
e9o=20.3;

e1p=2021;
e2p=2021;
e3p=2021;
e4p=2023;
e5p=2022.1;
e6p=2023;
e7p=2022.1;
e8p=2022.2;
e9p=2021.3;


%state probabilities

q2o=qo;
q3o=(1-qo);
q4o=qo*qo;
q5o=qo*(1-qo);
q6o=(1-qo)*qo*qo;
q7o=(1-qo)*(1-qo)*qo;
q8o=(1-qo)*(1-qo)*qo;
q9o=(1-qo)*(1-qo)*(1-qo);

q2p=qp;
q3p=(1-qp);
q4p=qp*qp;
q5p=qp*(1-qp);
q6p=(1-qp)*qp*qp;
q7p=(1-qp)*(1-qp)*qp;
q8p=(1-qp)*(1-qp)*qp;
q9p=(1-qp)*(1-qp)*(1-qp);

%income

Io=p1*e1o+p2*e2o+p3*e3o+p4*e4o+p5*e5o+p6*e6o+p7*e7o+p8*e8o+p9*e9o;
Ip=p1*e1p+p2*e2p+p3*e3p+p4*e4p+p5*e5p+p6*e6p+p7*e7p+p8*e8p+p9*e9p;

%Foc

f1= (1/x1o)-z1*p1;
f2= q2o*(1/x2o)-z1*p2;
f3= q3o*(1/x3o)-z1*p3;
f4= q4o*(1/x4o)-z1*p4;
f5= q5o*(1/x5o)-z1*p5;
f6= q6o*(1/x6o)-z1*p6;
f7= q7o*(1/x7o)-z1*p7;
f8= q8o*(1/x8o)-z1*p8;
f9= q9o*(1/x9o)-z1*p9;

f10= (1/x1p)-z2*p1;
f11= q2p*(1/x2p)-z2*p2;
f12= q3p*(1/x3p)-z2*p3;
f13= q4p*(1/x4p)-z2*p4;
f14= q5p*(1/x5p)-z2*p5;
f15= q6p*(1/x6p)-z2*p6;
f16= q7p*(1/x7p)-z2*p7;
f17= q8p*(1/x8p)-z2*p8;
f18= q9p*(1/x9p)-z2*p9;


%budget constraints

f19=p1*x1o+p2*x2o+p3*x3o+p4*x4o+p5*x5o+p6*x6o+p7*x7o+p8*x8o+p9*x9o-Io;
f20=p1*x1p+p2*x2p+p3*x3p+p4*x4p+p5*x5p+p6*x6p+p7*x7p+p8*x8p+p9*x9p-Ip;

%market clearing

f21=x2o+x2p-e2o-e2p;
f22=x3o+x3p-e3o-e3p;
f23=x4o+x4p-e4o-e4p;
f24=x5o+x5p-e5o-e5p;
f25=x6o+x6p-e6o-e6p;
f26=x7o+x7p-e7o-e7p;
f27=x8o+x8p-e8o-e8p;
f28=x9o+x9p-e9o-e9p;

sol=solve(f1,f2,f3,f4,f5,f6,f7,f8,f9, f10, f11, f12, f13, f14, f15, f16, f17, f18, f19, f20, f21, f22, f23, f24, f25, f26, f27, f28)

%variables (arrow debreu prices, consumption and multimpliers)

S.p2=double(sol.p2);
S.p3=double(sol.p3);
S.p4=double(sol.p4);
S.p5=double(sol.p5);
S.p6=double(sol.p6);
S.p7=double(sol.p7);
S.p8=double(sol.p8);
S.p9=double(sol.p9);
S.x1o=double(sol.x1o);
S.x2o=double(sol.x2o);
S.x3o=double(sol.x3o);
S.x4o=double(sol.x4o);
S.x5o=double(sol.x5o);
S.x6o=double(sol.x6o);
S.x7o=double(sol.x7o);
S.x8o=double(sol.x8o);
S.x9o=double(sol.x9o);
S.x1p=double(sol.x1p);
S.x2p=double(sol.x2p);
S.x3p=double(sol.x3p);
S.x4p=double(sol.x4p);
S.x5p=double(sol.x5p);
S.x6p=double(sol.x6p);
S.x7p=double(sol.x7p);
S.x8p=double(sol.x8p);
S.x9p=double(sol.x9p);
S.z1=double(sol.z1);
S.z2=double(sol.z2);


%asset prices from arrow prices

p1H=S.p4*1+S.p5*1+S.p6*1+S.p7*1+S.p8*0.2+S.p9*0.2;
p1E=S.p4*1+S.p5*0.1+S.p6*1+S.p7*0.1+S.p8*1+S.p9*0.1;
p2H=(S.p4*1+S.p5*1)/S.p2;
p2E=(S.p4*1+S.p5*0.1)/S.p2;

p3H=(S.p6*1+ S.p7*1+ S.p8*0.2 + S.p9*0.2)/S.p3;
p3E=(S.p6*1+S.p7*0.1+S.p8*1+S.p9*0.1)/S.p3;

p.p1H=p1H;
p.p1E=p1E;
p.p2H=p2H;
p.p2E=p2E;
p.p3H=p3H;
p.p3E=p3E;

S
p

CE= (p2E-p3E)/p1E*100
FE= (p1E-p3E)/p1E*100
CH= (p2H-p3H)/p2H*100
FH= (p1H-p3H)/p1H*100



